.. pathos documentation master file

pathos package documentation
============================

.. automodule:: pathos
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    pathos
    scripts

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
